<?php
/*
Template Name: コメント一覧
*/

// 1ページあたりの表示数
$per_page = 10;
// コメントの数を得る
$count_obj = wp_count_comments();
$comments_count = $count_obj->approved;
// 総ページ数を求める
$page_counts = ceil($comments_count / $per_page);
// 現在のページ番号を得る
$page_no = intval($wp_query->get('paged'));
// ページ番号が1より小さければ1にする
if ($page_no < 1) {
	$page_no = 1;
}
// ページ番号がページ数より大きければ、ページ数に合わせる
if ($page_no > $page_counts) {
	$page_no = $page_counts;
}
// オフセットを求める
$offset = ($page_no - 1) * $per_page;
// ページの先頭／最後のコメント番号を求める
$start_comment_no = $offset + 1;
$last_comment_no = $offset + $per_page > $comments_count ? $comments_count : $offset + $per_page;
// コメントを読み込む
$comments = get_comments("status=approve&number=${per_page}&offset=${offset}");
// コメントを投稿ごとにまとめる
$comments_to_post = array();
$post_ids = array();
foreach ($comments as $comment) {
	if (!isset($comments_to_post[$comment->comment_post_ID])) {
		$comments_to_post[$comment->comment_post_ID] = array();
		array_push($post_ids, $comment->comment_post_ID);
	}
	array_push($comments_to_post[$comment->comment_post_ID], $comment);
}
?>

<?php get_header(); ?>

		<div id="container">
			<div id="content" role="main">

				<h2>コメント一覧(<?php echo $comment_counts; ?>件中の<?php echo $start_comment_no; ?>～<?php echo $last_comment_no; ?>件目)</h2>
				<ul class="comments-list">
				<?php foreach ($post_ids as $post_id) : $post = get_post($post_id); setup_postdata($post); ?>
					<li>「<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>」へのコメント
					<ul>
						<?php foreach ($comments_to_post[$post_id] as $comment) : ?>
						<li>
							<?php echo get_avatar($comment, $size = '32'); ?>
							<?php comment_author_link(); ?>より<br />
							(<?php comment_time('Y/m/d H:i'); ?>)<br style="clear : both;" />
							<?php comment_text(); ?>
							<div style="clear : both;"></div>
						</li>
						<?php endforeach; ?>
					</ul>
					</li>
				<?php endforeach; ?>
				</ul>

				<?php if ($page_counts > 1) : ?>
				<p class="page-list">
					<?php if ($page_no != 1) : ?>
					<span><a href="<?php echo get_pagenum_link(1); ?>">&laquo;</a></span>
					<span><a href="<?php echo get_pagenum_link($page_no - 1); ?>">&lt;</a></span>
					<?php endif; ?>
					<?php for ($i = 1; $i <= $page_counts; $i++) : ?>
						<?php if ($i == $page_no) : ?>
							<span><?php echo $i; ?></span>
						<?php else : ?>
							<span><a href="<?php echo get_pagenum_link($i); ?>"><?php echo $i; ?></a></span>
						<?php endif; ?>
					<?php endfor; ?>
					<?php if ($page_no != $page_counts) : ?>
					<span><a href="<?php echo get_pagenum_link($page_no + 1); ?>">&gt;</a></span>
					<span><a href="<?php echo get_pagenum_link($page_counts); ?>">&raquo;</a></span>
					<?php endif; ?>
				</p>
				<?php endif; ?>

			</div><!-- #content -->
		</div><!-- #container -->

<?php get_sidebar(); ?>
<?php get_footer(); ?>
