<?php
/*
Plugin Name: Same Category Posts
Plugin URI: http://www.h-fj.com/blog/wpplgdoc/
Description: 現在出力中の投稿と同一カテゴリーに属する投稿の一覧を出力します。
Version: 1.0
Author: 藤本　壱
Author URI: http://www.h-fj.com/blog/
*/

function same_category_posts($args = '') {
	// グローバル変数の$wp_queryを使う
	global $wp_query;

	// パラメータのデフォルト値
	$defaults = array(
		'numberposts' => -1,
		'show_current' => 1,
		'current_no_link' => 1,
		'before_cat' => '「',
		'after_cat' => '」カテゴリーの投稿',
		'before_cat_tag' => '<h3 class="widget-title">',
		'after_cat_tag' => '</h3>',
		'before_list_tag' => '<li class="widget-container">',
		'after_list_tag' => '</li>',
		'show_counts' => 0,
		'orderby' => 'date',
		'order' => 'DESC',
		'echo' => 1,
	);
	// パラメータを分解する
	$r = wp_parse_args($args, $defaults);

	// 出力を保存する変数（$out）を初期化する
	$out = '';
	// 単体投稿ページのときだけ処理を行う
	if (is_single()) {
		// 現在表示中の投稿を得る
		$cur_post = $wp_query->get_queried_object();
		// 投稿が属するカテゴリーを得る
		$post_cats = get_the_category($cur_post->ID);
		// 各カテゴリーについて繰り返す
		foreach ($post_cats as $post_cat) {
			// リスト全体の前のタグ（before_list_tag）を出力
			$out .= $r['before_list_tag'] . "\n";
			// カテゴリー名の前のタグ（before_cat_tag）と文字列（before_cat）を出力
			$out .= $r['before_cat_tag'] . $r['before_cat'];
			// カテゴリー名を出力し、その部分をカテゴリーアーカイブページへのリンクにする
			$out .= '<a href="' . get_category_link($post_cat->cat_ID) . '">' . $post_cat->name . '</a>';
			// カテゴリー名の後の文字列（after_cat）を出力
			$out .= $r['after_cat'];
			// 「show_counts=1」が指定されている場合は、カテゴリーに属する投稿数を出力
			if ($r['show_counts']) {
				$out .= '(' . $post_cat->category_count . ')';
			}
			// カテゴリー名の後のタグを出力
			$out .= $r['after_cat_tag'] . "\n";
			// 投稿のリストの先頭のulタグを出力
			$out .= "<ul>\n";
			// 同一カテゴリーの投稿を読み込む
			$q = 'category=' . $post_cat->cat_ID;
			$q .= '&numberposts=' . $r['numberposts'];
			$q .= '&orderby=' . $r['orderby'];
			$q .= '&order=' . $r['order'];
			$cat_posts = get_posts($q);
			// 各投稿について繰り返す
			foreach ($cat_posts as $post) {
				setup_postdata($post);
				// 現在表示中の投稿と、リストに出力する投稿が同じ場合
				if ($post->ID == $cur_post->ID) {
					// 「show_current=1」が指定されている場合
					if ($r['show_current']) {
						// 「current_no_link=1」が指定されている場合は、
						// 投稿のタイトルをspanタグで囲む
						if ($r['current_no_link']) {
							$title_before = '<span class="current_post">';
							$title_after  = '</span>';
						}
						// 「current_no_link=1」が指定されている場合は、
						// 投稿のタイトルをaタグで囲む
						else {
							$title_before = '<a href="' . get_permalink($post->ID) . '">';
							$title_after  = '</a>';
						}
						// 投稿のタイトルを出力するためのHTMLを組み立てる
						$out .= '<li>' . $title_before . get_the_title($post->ID) . $title_after . "</li>\n";
					}
				}
				// 現在表示中の投稿と、リストに出力する投稿が異なる場合
				else {
					// 投稿のタイトルを出力するためのHTMLを組み立てる
					$out .= '<li><a href="' . get_permalink($post->ID) . '">' . get_the_title($post->ID) . "</a></li>\n";
				}
			}
			// 投稿のリストの最後の</ul>タグを出力
			$out .= "</ul>\n";
			// リスト全体の最後のタグを出力
			$out .= $r['after_list_tag'] . "\n";
		}
	}
	// フィルターを呼び出す
	$out = apply_filters('same_category_posts', $out);
	// 「echo=1」が指定されている場合は、結果をWebブラウザに出力する
	if ($r['echo']) {
		echo $out;
	}
	// 「echo=1」が指定されていない場合は、結果を戻り値として返す
	else {
		return $out;
	}
}
?>
