<?php
/*
Plugin Name: Same Category Posts
Plugin URI: http://www.h-fj.com/blog/wpplgdoc/
Description: 現在出力中の投稿と同一カテゴリーに属する投稿の一覧を出力します。
Version: 1.0
Author: 藤本　壱
Author URI: http://www.h-fj.com/blog/
*/

function same_category_posts($args = '') {
	// グローバル変数の$wp_queryを使う
	global $wp_query;

	// パラメータのデフォルト値
	$defaults = array(
		'numberposts' => get_option('fjscp_numberposts'),
		'show_current' => get_option('fjscp_show_current'),
		'current_no_link' => get_option('fjscp_current_no_link'),
		'before_cat' => get_option('fjscp_before_cat'),
		'after_cat' => get_option('fjscp_after_cat'),
		'before_cat_tag' => get_option('fjscp_before_cat_tag'),
		'after_cat_tag' => get_option('fjscp_after_cat_tag'),
		'before_list_tag' => get_option('fjscp_before_list_tag'),
		'after_list_tag' => get_option('fjscp_after_list_tag'),
		'show_counts' => get_option('fjscp_show_counts'),
		'orderby' => get_option('fjscp_orderby'),
		'order' => get_option('fjscp_order'),
		'echo' => 1,
	);
	// パラメータを分解する
	$r = wp_parse_args($args, $defaults);
	// 出力を保存する変数（$out）を初期化する
	$out = '';
	// 単体投稿ページのときだけ処理を行う
	if (is_single()) {
		// 現在表示中の投稿を得る
		$cur_post = $wp_query->get_queried_object();
		// 投稿が属するカテゴリーを得る
		$post_cats = get_the_category($cur_post->ID);
		// 各カテゴリーについて繰り返す
		foreach ($post_cats as $post_cat) {
			// リスト全体の前のタグ（before_list_tag）を出力
			$out .= $r['before_list_tag'] . "\n";
			// カテゴリー名の前のタグ（before_cat_tag）と文字列（before_cat）を出力
			$out .= $r['before_cat_tag'] . $r['before_cat'];
			// カテゴリー名を出力し、その部分をカテゴリーアーカイブページへのリンクにする
			$out .= '<a href="' . get_category_link($post_cat->cat_ID) . '">' . $post_cat->name . '</a>';
			// カテゴリー名の後の文字列（after_cat）を出力
			$out .= $r['after_cat'];
			// 「show_counts=1」が指定されている場合は、カテゴリーに属する投稿数を出力
			if ($r['show_counts']) {
				$out .= '(' . $post_cat->category_count . ')';
			}
			// カテゴリー名の後のタグを出力
			$out .= $r['after_cat_tag'] . "\n";
			// 投稿のリストの先頭のulタグを出力
			$out .= "<ul>\n";
			// 同一カテゴリーの投稿を読み込む
			$q = 'category=' . $post_cat->cat_ID;
			$q .= '&numberposts=' . $r['numberposts'];
			$q .= '&orderby=' . $r['orderby'];
			$q .= '&order=' . $r['order'];
			$cat_posts = get_posts($q);
			// 各投稿について繰り返す
			foreach ($cat_posts as $post) {
				setup_postdata($post);
				// 現在表示中の投稿と、リストに出力する投稿が同じ場合
				if ($post->ID == $cur_post->ID) {
					// 「show_current=1」が指定されている場合
					if ($r['show_current']) {
						// 「current_no_link=1」が指定されている場合は、
						// 投稿のタイトルをspanタグで囲む
						if ($r['current_no_link']) {
							$title_before = '<span class="current_post">';
							$title_after  = '</span>';
						}
						// 「current_no_link=1」が指定されている場合は、
						// 投稿のタイトルをaタグで囲む
						else {
							$title_before = '<a href="' . get_permalink($post->ID) . '">';
							$title_after  = '</a>';
						}
						// 投稿のタイトルを出力するためのHTMLを組み立てる
						$out .= '<li>' . $title_before . get_the_title($post->ID) . $title_after . "</li>\n";
					}
				}
				// 現在表示中の投稿と、リストに出力する投稿が異なる場合
				else {
					// 投稿のタイトルを出力するためのHTMLを組み立てる
					$out .= '<li><a href="' . get_permalink($post->ID) . '">' . get_the_title($post->ID) . "</a></li>\n";
				}
			}
			// 投稿のリストの最後の</ul>タグを出力
			$out .= "</ul>\n";
			// リスト全体の最後のタグを出力
			$out .= $r['after_list_tag'] . "\n";
		}
	}
	// フィルターを呼び出す
	$out = apply_filters('same_category_posts', $out);
	// 「echo=1」が指定されている場合は、結果をWebブラウザに出力する
	if ($r['echo']) {
		echo $out;
	}
	// 「echo=1」が指定されていない場合は、結果を戻り値として返す
	else {
		return $out;
	}
}

// 設定の初期値を保存
function same_category_posts_init_options() {
	// 「fjscp_installed」の設定項目が保存されていないときだけ
	// 初期化の処理を行う
	if (!get_option('fjscp_installed')) {
		update_option('fjscp_numberposts', -1);
		update_option('fjscp_show_current', 1);
		update_option('fjscp_current_no_link', 1);
		update_option('fjscp_before_cat', '「');
		update_option('fjscp_after_cat', '」カテゴリーの投稿');
		update_option('fjscp_before_cat_tag', '<h3 class="widget-title">');
		update_option('fjscp_after_cat_tag', '</h3>');
		update_option('fjscp_before_list_tag', '<li class="widget-container">');
		update_option('fjscp_after_list_tag', '</li>');
		update_option('fjscp_show_counts', 0);
		update_option('fjscp_orderby', 'date');
		update_option('fjscp_order', 'DESC');
		update_option('fjscp_installed', 1);
	}
}
register_activation_hook(__FILE__, 'same_category_posts_init_options');

// 「プラグイン」メニューのサブメニューに「Same Category Postsの設定」を追加
function same_category_posts_add_admin_menu() {
	add_submenu_page('plugins.php', 'Same Category Postsの設定', 'Same Category Postsの設定', 8, __FILE__, 'same_category_posts_admin_page');
}
add_action('admin_menu', 'same_category_posts_add_admin_menu');

// 設定画面の表示
function same_category_posts_admin_page() {
	// 「変更を保存」ボタンがクリックされたときは、設定を保存する
	if ($_POST['posted'] == 'Y') {
		update_option('fjscp_numberposts', intval($_POST['numberposts']));
		update_option('fjscp_show_current', intval($_POST['show_current']));
		update_option('fjscp_current_no_link', intval($_POST['current_no_link']));
		update_option('fjscp_before_cat', stripslashes($_POST['before_cat']));
		update_option('fjscp_after_cat', stripslashes($_POST['after_cat']));
		update_option('fjscp_before_cat_tag', stripslashes($_POST['before_cat_tag']));
		update_option('fjscp_after_cat_tag', stripslashes($_POST['after_cat_tag']));
		update_option('fjscp_before_list_tag', stripslashes($_POST['before_list_tag']));
		update_option('fjscp_after_list_tag', stripslashes($_POST['after_list_tag']));
		update_option('fjscp_show_counts', intval($_POST['show_counts']));
		update_option('fjscp_orderby', stripslashes($_POST['orderby']));
		update_option('fjscp_order', stripslashes($_POST['order']));
	}
?>
<?php if($_POST['posted'] == 'Y') : ?><div class="updated"><p><strong>設定を保存しました</strong></p></div><?php endif; ?>
<?php if($_POST['posted'] == 'Y') : ?>
<!-- order = <?php echo $_POST['order']; ?>, striped = <?php echo stripslashes($_POST['order']); ?>, saved = <?php get_option('fjscp_order'); ?> -->
<?php endif; ?>
<div class="wrap">
	<h2>Same Category Postsの設定</h2>
	<form method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
		<input type="hidden" name="posted" value="Y">
		<table class="form-table">
			<tr valign="top">
				<th scope="row"><label for="numberposts">表示する投稿の数<label></th>
				<td>
					<input name="numberposts" type="text" id="numberposts" value="<?php echo get_option('fjscp_numberposts'); ?>" class="regular-text code" /><br />
					-1を指定すると、同一カテゴリーの投稿をすべて表示します。
				</td>
			</tr>
			<tr valign="top">
				<th scope="row">現在表示中の投稿の表示</th>
				<td>
					<input name="show_current" type="checkbox" id="show_current" value="1"<?php if (get_option('fjscp_show_current')) : ?> checked="checked"<?php endif; ?> />
					<label for="show_current">現在表示中の投稿を同一カテゴリー投稿リストに出力する<label>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row">現在表示中の投稿へのリンク</th>
				<td>
					<input name="current_no_link" type="checkbox" id="current_no_link" value="1"<?php if (get_option('fjscp_current_no_link')) : ?> checked="checked"<?php endif; ?> />
					<label for="current_no_link">現在表示中の投稿を同一カテゴリー投稿リストに出力する場合、その投稿はリンクにしない<label>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="before_cat">カテゴリー名の前<label></th>
				<td>
					<input name="before_cat" type="text" id="before_cat" value="<?php echo esc_attr(get_option('fjscp_before_cat')); ?>" class="regular-text code" /><br />カテゴリー名の前に出力する文字列を指定します。
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="after_cat">カテゴリー名の後<label></th>
				<td>
					<input name="after_cat" type="text" id="after_cat" value="<?php echo esc_attr(get_option('fjscp_after_cat')); ?>" class="regular-text code" /><br />カテゴリー名の後に出力する文字列を指定します。
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="before_cat_tag">カテゴリーの前のタグ<label></th>
				<td>
					<input name="before_cat_tag" type="text" id="before_cat_tag" value="<?php echo esc_attr(get_option('fjscp_before_cat_tag')); ?>" class="regular-text code" /><br />カテゴリーの前に出力するタグを指定します。
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="after_cat_tag">カテゴリーの後のタグ<label></th>
				<td>
					<input name="after_cat_tag" type="text" id="after_cat_tag" value="<?php echo esc_attr(get_option('fjscp_after_cat_tag')); ?>" class="regular-text code" /><br />カテゴリーの後に出力するタグを指定します。
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="before_list_tag">リストの前のタグ<label></th>
				<td>
					<input name="before_list_tag" type="text" id="before_list_tag" value="<?php echo esc_attr(get_option('fjscp_before_list_tag')); ?>" class="regular-text code" /><br />同一カテゴリー投稿リストの前に出力するタグを指定します。
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="after_list_tag">リストの後のタグ<label></th>
				<td>
					<input name="after_list_tag" type="text" id="after_list_tag" value="<?php echo esc_attr(get_option('fjscp_after_list_tag')); ?>" class="regular-text code" /><br />同一カテゴリー投稿リストの後に出力するタグを指定します。
				</td>
			</tr>
			<tr valign="top">
				<th scope="row">投稿数の表示</th>
				<td>
					<input name="show_counts" type="checkbox" id="show_counts" value="1"<?php if (get_option('fjscp_show_counts')) : ?> checked="checked"<?php endif; ?> /><label for="show_counts">カテゴリー名のあとに、そのカテゴリに属する投稿の件数を表示する<label>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="orderby">投稿の並び順のキー</label></th>
				<td>
					<select name="orderby" id="orderby">
					<?php
						$options = array(
							array('value' => 'date', 'text' => '日付'),
							array('value' => 'title', 'text' => 'タイトル'),
						);
						foreach ($options as $option) : ?>
						<option value="<?php echo $option['value']; ?>"<?php if (get_option('fjscp_orderby') == $option['value']) : ?> selected="selected"<?php endif; ?>><?php echo $option['text']; ?></option>
					<?php endforeach; ?>
					</select><br />同一カテゴリー投稿の一覧を並べ替えるキーを指定します。
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="order">投稿の並び順</label></th>
				<td>
					<select name="order" id="order">
					<?php
						$options = array(
							array('value' => 'ASC', 'text' => '昇順'),
							array('value' => 'DESC', 'text' => '降順'),
						);
						foreach ($options as $option) : ?>
						<option value="<?php echo esc_attr($option['value']); ?>"<?php if (get_option('fjscp_order') == $option['value']) : ?> selected="selected"<?php endif; ?>><?php echo esc_attr($option['text']); ?></option>
					<?php endforeach; ?>
					</select><br />同一カテゴリー投稿の一覧の並び順を指定します。
				</td>
			</tr>
		</table>

		<p class="submit">
			<input type="submit" name="Submit" class="button-primary" value="変更を保存" />
		</p>
	</form>
</div>
<?php
}
?>
